@@ -1,9 +1,10 @@
-#include <Rcpp.h>
-using namespace Rcpp;
+#include "utils.h"
+#include <cpp11/environment.hpp>
+#include <vector>
 
-// [[Rcpp::export]]
-std::string obj_addr_(SEXP x) {
-  return tfm::format("%p", x);
+[[cpp11::register]]
+std::string obj_addr_(SEXP name, cpp11::environment env) {
+  return obj_addr_(Rf_eval(name, env));
 }
 
 void frame_addresses(SEXP frame, std::vector<std::string>* refs) {
@@ -19,7 +20,7 @@ void hash_table_addresses(SEXP table, std::vector<std::string>* refs) {
     frame_addresses(VECTOR_ELT(table, i), refs);
 }
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 std::vector<std::string> obj_addrs_(SEXP x) {
   int n = Rf_length(x);
   std::vector<std::string> out;
@@ -38,17 +39,20 @@ std::vector<std::string> obj_addrs_(SEXP x) {
     break;
 
   case ENVSXP: {
-    bool isHashed = HASHTAB(x) != R_NilValue;
+    // Using node-based object accessors: CAR for FRAME, and TAG for HASHTAB.
+    // TODO: Iterate over environments using environment accessors.
+    // We won't be able to provide an address for things like promises though.
+    bool isHashed = TAG(x) != R_NilValue;
     if (isHashed) {
-      hash_table_addresses(HASHTAB(x), &out);
+      hash_table_addresses(TAG(x), &out);
     } else {
-      frame_addresses(FRAME(x), &out);
+      frame_addresses(CAR(x), &out);
     }
     break;
   }
 
   default:
-    Rcpp::stop(
+    cpp11::stop(
       "`x` must be a list, environment, or character vector, not a %s.",
       Rf_type2char(TYPEOF(x))
     );
